
**AllSpeak** is a pythonic (yet ironically inspired by Rails) i18n/l10n solution for humans doing Python web applications.  It's flexible, easy to use and —unlike gettext— independent of any external compilation tool.

The library is MIT Licensed and compatible with Werkzeug, Webob and Django request objects, so you can use it with pretty much any WSGI-based framework.

 See the documentation online at http://lucuma.github.com/allspeak
